@@ -160,14 +160,14 @@ class MediaPlayer2Service(dbus.service.Object):
 
         try:
             lastUsed = media.get_last_played()
-            assert genre is not None
+            assert lastUsed is not None
             metadata['xesam:lastUsed'] = lastUsed
         except:
             pass
 
         try:
             artUrl = media.get_thumbnail()
-            assert genre is not None
+            assert artUrl is not None
             metadata['mpris:artUrl'] = artUrl
         except:
             pass
@@ -278,7 +278,7 @@ class MediaPlayer2Service(dbus.service.Object):
         elif self.first_song_handler == 0:
             window = self.app.get_active_window()
             window._stack.set_visible_child(window.views[2])
-            model = window.views[2].filter
+            model = window.views[2]._model
             if model.iter_n_children(None):
                 _iter = model.get_iter_first()
                 self._play_first_song(model, model.get_path(_iter), _iter)
