@@ -270,8 +270,11 @@ class ViewContainer(Gtk.Stack):
     @log
     def _on_discovered(self, info, error, _iter):
         if error:
-            print("Info %s: error: %s" % (info, error))
-            self._model.set(_iter, [8, 10], [self.errorIconName, True])
+            try:
+                logger.warn("File will be skipped: %s\n%s" % (error.message, info.get_uri()))
+                self._model.set(_iter, [8, 10], [self.errorIconName, True])
+            except Exception:
+                pass
 
     @log
     def _add_item(self, source, param, item, remaining=0, data=None):
@@ -291,7 +294,7 @@ class ViewContainer(Gtk.Stack):
                 try:
                     self.player.discoverer.discover_uri(item.get_url())
                 except:
-                    print('failed to discover url ' + item.get_url())
+                    logger.warn('failed to discover url ' + item.get_url())
                     icon_name = self.errorIconName
             self._model.set(_iter,
                             [0, 1, 2, 3, 4, 5, 7, 8, 9, 10],
@@ -369,7 +372,10 @@ class Albums(ViewContainer):
 
     @log
     def _on_item_activated(self, widget, id, path):
-        _iter = self._model.get_iter(path)
+        try:
+            _iter = self._model.get_iter(path)
+        except TypeError:
+            return
         title = self._model.get_value(_iter, 2)
         artist = self._model.get_value(_iter, 3)
         item = self._model.get_value(_iter, 5)
@@ -454,7 +460,10 @@ class Songs(ViewContainer):
 
     @log
     def _on_item_activated(self, widget, id, path):
-        _iter = self._model.get_iter(path)
+        try:
+            _iter = self._model.get_iter(path)
+        except TypeError:
+            return
         if self._model.get_value(_iter, 8) != self.errorIconName:
             self.player.set_playlist('Songs', None, self._model, _iter, 5)
             self.player.set_playing(True)
@@ -664,7 +673,10 @@ class Artists (ViewContainer):
 
     @log
     def _on_item_activated(self, widget, item_id, path):
-        _iter = self._model.get_iter(path)
+        try:
+            _iter = self._model.get_iter(path)
+        except TypeError:
+            return
         self._last_selection = _iter
         artist = self._model.get_value(_iter, 2)
         albums = self._artists[artist.casefold()]['albums']
@@ -999,7 +1011,10 @@ class Playlist(ViewContainer):
 
     @log
     def _on_item_activated(self, widget, id, path):
-        _iter = self._model.get_iter(path)
+        try:
+            _iter = self._model.get_iter(path)
+        except TypeError:
+            return
         if self._model.get_value(_iter, 8) != self.errorIconName:
             self.player.set_playlist(
                 'Playlist', self.current_playlist.get_id(),
@@ -1227,6 +1242,7 @@ class Search(ViewContainer):
 
     @log
     def _back_button_clicked(self, widget, data=None):
+        self.header_bar.searchbar.show_bar(True, False)
         if self.get_visible_child() == self._artistAlbumsWidget:
             self._artistAlbumsWidget.destroy()
             self._artistAlbumsWidget = None
@@ -1234,7 +1250,10 @@ class Search(ViewContainer):
 
     @log
     def _on_item_activated(self, widget, id, path):
-        child_path = self.filter_model.convert_path_to_child_path(path)
+        try:
+            child_path = self.filter_model.convert_path_to_child_path(path)
+        except TypeError:
+            return
         _iter = self._model.get_iter(child_path)
         if self._model[_iter][11] == 'album':
             title = self._model.get_value(_iter, 2)
