@@ -349,6 +349,8 @@ class ArtistAlbums(Gtk.VBox):
         self._hbox.pack_start(self.ui.get_object('ArtistAlbumsWidget'),
                               False, False, 0)
         self._hbox.pack_start(self._albumBox, False, False, 16)
+        self._coverSizeGroup = Gtk.SizeGroup.new(Gtk.SizeGroupMode.HORIZONTAL)
+        self._songsGridSizeGroup = Gtk.SizeGroup.new(Gtk.SizeGroupMode.HORIZONTAL)
         self.pack_start(self._scrolledWindow, True, True, 0)
 
         for album in albums:
@@ -363,6 +365,8 @@ class ArtistAlbums(Gtk.VBox):
             self.artist, album, self.player, self.model,
             self.header_bar, self.selectionModeAllowed
         )
+        self._coverSizeGroup.add_widget(widget.cover)
+        self._songsGridSizeGroup.add_widget(widget.songsGrid)
         self._albumBox.pack_start(widget, False, False, 0)
         self.widgets.append(widget)
 
@@ -484,7 +488,9 @@ class ArtistAlbumWidget(Gtk.HBox):
 
         GLib.idle_add(self._update_album_art)
 
-        self.ui.get_object('cover').set_from_pixbuf(self.pixbuf)
+        self.cover = self.ui.get_object('cover')
+        self.cover.set_from_pixbuf(self.pixbuf)
+        self.songsGrid = self.ui.get_object('grid1')
         self.ui.get_object('title').set_label(album.get_title())
         if album.get_creation_date():
             self.ui.get_object('year').set_markup(
@@ -522,7 +528,7 @@ class ArtistAlbumWidget(Gtk.HBox):
                 title = AlbumArtCache.get_media_title(track)
                 ui.get_object('title').set_text(title)
                 ui.get_object('title').set_alignment(0.0, 0.5)
-                self.ui.get_object('grid1').attach(
+                self.songsGrid.attach(
                     song_widget,
                     int(i / (len(self.tracks) / 2)),
                     int(i % (len(self.tracks) / 2)), 1, 1
@@ -551,7 +557,7 @@ class ArtistAlbumWidget(Gtk.HBox):
                 song_widget.can_be_played = True
                 song_widget.connect('button-release-event',
                                     self.track_selected)
-            self.ui.get_object('grid1').show_all()
+            self.songsGrid.show_all()
 
     @log
     def _update_album_art(self):
@@ -565,7 +571,7 @@ class ArtistAlbumWidget(Gtk.HBox):
     @log
     def _get_album_cover(self, pixbuf, path, data=None):
         if pixbuf:
-            self.ui.get_object('cover').set_from_pixbuf(pixbuf)
+            self.cover.set_from_pixbuf(pixbuf)
 
     @log
     def track_selected(self, widget, event):
@@ -728,7 +734,8 @@ class PlaylistDialog():
     @log
     def _on_playlist_created(self, playlists, item):
         new_iter = self._add_item_to_model(item)
-        self.view.set_cursor(self.model.get_path(new_iter),
-                             self.view.get_columns()[0], False)
-        self.view.row_activated(self.model.get_path(new_iter),
-                                self.view.get_columns()[0])
+        if self.view.get_columns():
+            self.view.set_cursor(self.model.get_path(new_iter),
+                                 self.view.get_columns()[0], False)
+            self.view.row_activated(self.model.get_path(new_iter),
+                                    self.view.get_columns()[0])
